<?php

add_action('admin_menu', 'sidetracker_add_admin_menu');

function sidetracker_add_admin_menu() {
    add_menu_page('Sidetracker Settings', 'Sidetracker', 'manage_options', 'sidetracker-settings', 'sidetracker_settings_page', 'dashicons-admin-generic');
    add_submenu_page('sidetracker-settings', 'Manage Actions', 'Manage Actions', 'manage_options', 'sidetracker-actions', 'sidetracker_manage_actions_page');
    add_submenu_page('sidetracker-settings', 'Add/Edit Action', 'Add/Edit Action', 'manage_options', 'sidetracker-add-action', 'sidetracker_add_action_page');
}

function sidetracker_settings_page() {
    ?>
    <div class="wrap">
        <h2>Sidetracker Settings</h2>
        <form method="post" action="options.php">
            <?php
            settings_fields('sidetracker-settings');
            do_settings_sections('sidetracker-settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

add_action('admin_init', 'sidetracker_settings_init');

function sidetracker_settings_init() {
    register_setting('sidetracker-settings', 'sidetracker_api_key');
    register_setting('sidetracker-settings', 'sidetracker_action_url');
    // Add more settings initialization as needed

    add_settings_section(
        'sidetracker_api_settings',
        'API Settings',
        'sidetracker_api_settings_section_callback',
        'sidetracker-settings'
    );

    add_settings_field(
        'sidetracker_api_key',
        'API Key',
        'sidetracker_api_key_render',
        'sidetracker-settings',
        'sidetracker_api_settings'
    );

    add_settings_field(
        'sidetracker_action_url',
        'sidetracker_action_url_render',
        'sidetracker-settings',
        'sidetracker_api_settings'
    );
}

function sidetracker_api_settings_section_callback() {
    echo 'Enter your Sidetracker API settings below.';
}

function sidetracker_api_key_render() {
    $options = get_option('sidetracker_api_key');
    ?>
    <input type='text' name='sidetracker_api_key' value='<?php echo $options; ?>'>
    <?php
}

function sidetracker_action_url_render() {
    $options = get_option('sidetracker_action_url');
    ?>
    <input type='text' name='sidetracker_action_url' value='<?php echo $options; ?>'>
    <?php
}

function sidetracker_get_action_details($actionId) {
    $actions = get_option('sidetracker_actions', []);
    if (isset($actions[$actionId])) {
        return $actions[$actionId];
    }
    return ['name' => '', 'url' => '', 'mappings' => []];
}

add_action('admin_post_sidetracker_save_action', 'handle_save_action');

function handle_save_action() {
    if (!current_user_can('manage_options')) {
        wp_die('You do not have sufficient permissions to access this page.');
    }

    check_admin_referer('save_action_nonce');
    
    global $wpdb;
    $table_name = $wpdb->prefix . 'sidetracker_actions';

    $action_id = isset($_POST['action_id']) ? intval($_POST['action_id']) : 0;
    $isEditing = ($action_id > 0);

    $mappings = [];
    if (isset($_POST['form_field_id']) && is_array($_POST['form_field_id'])) {
        foreach ($_POST['form_field_id'] as $index => $field_id) {
            $payload_key = sanitize_text_field($_POST['payload_key'][$index] ?? '');
            if ($payload_key !== '') {
                $mappings[$field_id] = $payload_key;
            }
        }
    }

    // Handling fixed parameters
    $fixed_parameters = [];
    if (isset($_POST['fixed_param_keys']) && is_array($_POST['fixed_param_keys'])) {
        $fixed_param_keys = $_POST['fixed_param_keys'];
        $fixed_param_values = $_POST['fixed_param_values'];
        foreach ($fixed_param_keys as $index => $key) {
            $value = sanitize_text_field($fixed_param_values[$index] ?? '');
            $key = sanitize_text_field($key);
            if ($key !== '' && $value !== '') {
                $fixed_parameters[$key] = $value;
            }
        }
    }

    // Capture the WPForms and Gravity Forms IDs from the POST data
    $wpform_id = isset($_POST['wpform_id']) && $_POST['wpform_id'] !== '' ? intval($_POST['wpform_id']) : null;
    $gravityform_id = isset($_POST['gravityform_id']) && $_POST['gravityform_id'] !== '' ? intval($_POST['gravityform_id']) : null;

    $action_data = [
        'name' => sanitize_text_field($_POST['action_name']),
        'type' => sanitize_text_field($_POST['action_type']),
        'url' => esc_url_raw($_POST['action_url']),
        'mappings' => maybe_serialize($mappings),
        'fixed_parameters' => maybe_serialize($fixed_parameters),
        'wpform_id' => $wpform_id,
        'gravityform_id' => $gravityform_id,
    ];

    $format = [
        '%s',
        '%s',
        '%s',
        '%s',
        '%s',
        $wpform_id === null ? '%d' : '%d',
        $gravityform_id === null ? '%d' : '%d',
    ];


    if ($isEditing) {
        $result = $wpdb->update($table_name, $action_data, ['id' => $action_id], $format);
    } else {
        $result = $wpdb->insert($table_name, $action_data, $format);
    }

    if ($result === false) {
        error_log('Database operation error: ' . $wpdb->last_error);
        wp_die('Database operation error: ' . $wpdb->last_error);
    }

    wp_redirect(admin_url('admin.php?page=sidetracker-actions'));
    exit;

}

function sidetracker_manage_actions_page() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'sidetracker_actions';

    $actions = $wpdb->get_results("SELECT * FROM $table_name", ARRAY_A);

    ?>
    <div class="wrap">
        <h2>Manage Actions</h2>
        <div style="text-align: right;">
            <a href="<?php echo admin_url('admin.php?page=sidetracker-add-action'); ?>" class="page-title-action">New action</a>
        </div>
        <p>Your Sidetracker events</p>

        <table class="widefat striped">
            <thead>
                <tr>
                    <th>Name</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php
                foreach ($actions as $action) {
                    echo '<tr>';
                    echo '<td>' . esc_html($action['name']) . '</td>';
                    echo '<td>';
                    echo '<a href="' . esc_url(admin_url('admin.php?page=sidetracker-add-action&action_id=' . $action['id'])) . '">Edit</a> | ';
                    echo '<a href="' . esc_url(wp_nonce_url(admin_url('admin-post.php?action=sidetracker_delete_action&action_id=' . $action['id']), 'sidetracker_delete_action_' . $action['id'])) . '" class="sidetracker-delete-action" onclick="return confirm(\'Are you sure you want to delete this action?\');">Delete</a>';
                    echo '</td>';
                    echo '</tr>';
                }
                ?>
            </tbody>
        </table>
    </div>
    <?php
}

add_action('admin_post_sidetracker_delete_action', 'handle_delete_action');

function handle_delete_action() {
    if (!current_user_can('manage_options') || !isset($_GET['action_id']) || !wp_verify_nonce($_GET['_wpnonce'], 'sidetracker_delete_action_' . $_GET['action_id'])) {
        wp_die('You are not allowed to perform this action.');
    }

    $action_id = intval($_GET['action_id']);
    global $wpdb;
    $table_name = $wpdb->prefix . 'sidetracker_actions';

    $wpdb->delete($table_name, ['id' => $action_id]);

    wp_redirect(admin_url('admin.php?page=sidetracker-actions'));
    exit;
}


function sidetracker_add_action_page() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'sidetracker_actions';
    $isEditing = isset($_GET['action_id']);
    $actionId = $isEditing ? intval($_GET['action_id']) : 0;
    $actionDetails = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE id = %d", $actionId), ARRAY_A) ?: ['name' => '', 'type' => '', 'url' => '', 'mappings' => [], 'fixed_parameters' => []];
    if ($actionDetails['mappings']) {
        $actionDetails['mappings'] = maybe_unserialize($actionDetails['mappings']);
    }
    if ($actionDetails['fixed_parameters']) {
        $actionDetails['fixed_parameters'] = maybe_unserialize($actionDetails['fixed_parameters']);
    }

    ?>
    <div class="wrap">
        <h2><?php echo $isEditing ? 'Edit Action' : 'Add New Action'; ?></h2>
        <form method="post" action="<?php echo admin_url('admin-post.php'); ?>">
            <input type="hidden" name="action" value="sidetracker_save_action">
            <input type="hidden" name="action_id" value="<?php echo esc_attr($actionId); ?>">

            <h3>Action Name</h3>
            <input type="text" name="action_name" value="<?php echo esc_attr($actionDetails['name']); ?>" class="regular-text">
            
            <h3>Action Type</h3>
            <select name="action_type" onchange="showFormOptions(this.value)">
                <option selected disabled>---Select action type---</option>
                <?php if (class_exists('wpforms')): ?>
                <option value="wpforms-submission" <?php echo ($actionDetails['type'] == 'wpforms-submission') ? 'selected' : ''; ?>>WPForms Submission</option>
                <?php endif; ?>
                <?php if (class_exists('GFAPI')): ?>
                <option value="gravityforms-submission" <?php echo ($actionDetails['type'] == 'gravityforms-submission') ? 'selected' : ''; ?>>Gravity Forms Submission</option>
                <?php endif; ?>
                <option value="wc-checkout" <?php echo ($actionDetails['type'] == 'wc-checkout') ? 'selected' : ''; ?>>WooCommerce Checkout</option>
            </select>

            <?php if (function_exists('wpforms')): ?>
            <div id="wpforms-options" style="<?php echo ($actionDetails['type'] == 'wpforms-submission') ? '' : 'display: none;'; ?>">
                <h3>WPForms</h3>
                <select name="wpform_id">
                    <?php
                    $forms = wpforms()->form->get();
                    foreach ($forms as $form) {
                        $selected = ($actionDetails['wpform_id'] == $form->ID) ? 'selected' : '';
                        echo '<option value="' . esc_attr($form->ID) . '"' . $selected . '>' . esc_html($form->post_title) . '</option>';
                    }
                    ?>
                </select>
            </div>
            <?php endif; ?>

            <?php if (class_exists('GFAPI')): ?>
            <div id="gravityforms-options" style="<?php echo ($actionDetails['type'] == 'gravityforms-submission') ? '' : 'display: none;'; ?>">
                <h3>Gravity Forms</h3>
                <select name="gravityform_id">
                    <?php
                    $gf_forms = GFAPI::get_forms();
                    foreach ($gf_forms as $form) {
                        $selected = ($actionDetails['gravityform_id'] == $form['id']) ? 'selected' : '';
                        echo '<option value="' . esc_attr($form['id']) . '" ' . $selected . '>' . esc_html($form['title']) . '</option>';
                    }
                    ?>
                </select>
            </div>
            <?php endif; ?>

            <h3>Request URL</h3>
            <input type="url" name="action_url" value="<?php echo esc_attr($actionDetails['url']); ?>" class="regular-text">
            
            
            <!-- Fixed Parameters Section -->
            <h3>Fixed Parameters</h3>
            <div id="fixed-parameters">
                <?php foreach ($actionDetails['fixed_parameters'] as $key => $value): ?>
                    <div class="fixed-parameter">
                        <input type="text" name="fixed_param_keys[]" placeholder="Key" value="<?php echo esc_attr($key); ?>">
                        <input type="text" name="fixed_param_values[]" placeholder="Value" value="<?php echo esc_attr($value); ?>">
                    </div>
                <?php endforeach; ?>
                <button type="button" onclick="addFixedParameter()">Add Fixed Parameter</button>
            </div>

            <h3>Payload Mapping</h3>
            <p>Map form field IDs to payload keys.</p>
            <div id="payload-mappings">
                <?php if (!empty($actionDetails['mappings']) && is_array($actionDetails['mappings'])): ?>
                    <?php foreach ($actionDetails['mappings'] as $form_field_id => $payload_key): ?>
                        <div class="mapping-field">
                            <input type="text" name="form_field_id[]" placeholder="Form Field ID" value="<?php echo esc_attr($form_field_id); ?>">
                            <input type="text" name="payload_key[]" placeholder="Payload Key" value="<?php echo esc_attr($payload_key); ?>">
                            <!-- Include a button or link to remove a mapping if needed -->
                        </div>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div>
            <button type="button" onclick="addMapping()">Add Mapping</button>

            <?php wp_nonce_field('save_action_nonce', '_wpnonce'); ?>
            <?php submit_button($isEditing ? 'Update Action' : 'Add Action'); ?>
        </form>
    </div>

    <script>
    function showFormOptions(value) {
        var wpformsOptionsDiv = document.getElementById('wpforms-options');
        var gravityFormsOptionsDiv = document.getElementById('gravityforms-options');

        if (wpformsOptionsDiv) {
            wpformsOptionsDiv.style.display = value === 'wpforms-submission' ? 'block' : 'none';
        }
        if (gravityFormsOptionsDiv) {
            gravityFormsOptionsDiv.style.display = value === 'gravityforms-submission' ? 'block' : 'none';
        }
    }

    document.querySelector('[name="action_type"]').addEventListener('change', function() {
        showFormOptions(this.value);
    });

    var actionTypeSelect = document.querySelector('[name="action_type"]');
    if (actionTypeSelect) {
        showFormOptions(actionTypeSelect.value);
    }

    function addMapping() {
        // Create a new div element to hold the mapping fields
        var mappingDiv = document.createElement("div");

        // Create input field for form field ID
        var formFieldIdInput = document.createElement("input");
        formFieldIdInput.type = "text";
        formFieldIdInput.name = "form_field_id[]";
        formFieldIdInput.placeholder = "Form Field ID";
        mappingDiv.appendChild(formFieldIdInput);

        // Create input field for payload key
        var payloadKeyInput = document.createElement("input");
        payloadKeyInput.type = "text";
        payloadKeyInput.name = "payload_key[]";
        payloadKeyInput.placeholder = "Payload Key";
        mappingDiv.appendChild(payloadKeyInput);

        // Append the mapping fields to the "payload-mappings" div
        document.getElementById("payload-mappings").appendChild(mappingDiv);
    }

    function addFixedParameter() {
        // Create a new div element to hold the fixed parameter fields
        var fixedParamDiv = document.createElement("div");
        fixedParamDiv.className = "fixed-parameter"; // Adding a class for potential styling

        // Create input field for the fixed parameter key
        var keyInput = document.createElement("input");
        keyInput.type = "text";
        keyInput.name = "fixed_param_keys[]";
        keyInput.placeholder = "Key";
        fixedParamDiv.appendChild(keyInput);

        // Create input field for the fixed parameter value
        var valueInput = document.createElement("input");
        valueInput.type = "text";
        valueInput.name = "fixed_param_values[]";
        valueInput.placeholder = "Value";
        fixedParamDiv.appendChild(valueInput);

        // Append the fixed parameter fields to the "fixed-parameters" div
        document.getElementById("fixed-parameters").appendChild(fixedParamDiv);
    }

    </script>

    <?php
}

?>