<?php

add_action('wpforms_process_complete', 'custom_wpforms_process_complete', 10, 4);
function custom_wpforms_process_complete($fields, $entry, $form_data, $entry_id) {
    sidetracker_log("WPForms submission processing started for form ID: " . $form_data['id']);

    global $wpdb;
    $table_name = $wpdb->prefix . 'sidetracker_actions';

    $actions = $wpdb->get_results($wpdb->prepare("SELECT * FROM $table_name WHERE type = 'wpforms-submission' AND wpform_id = %d", $form_data['id']), ARRAY_A);
    
    if (empty($actions)) {
        sidetracker_log('No actions found for this WPForms submission.');
        return;
    }

    foreach ($actions as $action) {
        $mappings = maybe_unserialize($action['mappings']);
        $fixed_parameters = maybe_unserialize($action['fixed_parameters']);
        $payload = [];

        if (is_array($fixed_parameters) && !empty($fixed_parameters)) {
            foreach ($fixed_parameters as $key => $value) {
                $payload[$key] = $value;
            }
        }

        foreach ($mappings as $form_field_id => $payload_key) {
            if (isset($fields[$form_field_id]['value'])) {
                $payload[$payload_key] = sanitize_text_field($fields[$form_field_id]['value']);
            }
        }

        $actionUrl = $action['url'];
        $apiKey = get_option('sidetracker_api_key');
        sidetracker_make_api_call($actionUrl, $payload, $apiKey);
    }
}


add_action('gform_after_submission', 'custom_gravityforms_process_complete', 10, 2);

function custom_gravityforms_process_complete($entry, $form) {
    sidetracker_log("Gravity Forms submission processing started for form ID: " . $form['id']);
    global $wpdb;
    $table_name = $wpdb->prefix . 'sidetracker_actions';
    $actions = $wpdb->get_results($wpdb->prepare("SELECT * FROM $table_name WHERE type = 'gravityforms-submission' AND gravityform_id = %d", $form['id']), ARRAY_A);

    if (empty($actions)) {
        sidetracker_log('No actions found for this Gravity Forms submission.');
        return;
    }

    $consolidatedEntries = [];
    foreach ($entry as $field_id => $value) {
        $base_field_id = explode('.', $field_id)[0];
        if (!isset($consolidatedEntries[$base_field_id])) {
            $consolidatedEntries[$base_field_id] = [];
        }
        $consolidatedEntries[$base_field_id][] = sanitize_text_field($value);
    }

    foreach ($actions as $action) {
        $mappings = maybe_unserialize($action['mappings']);
        $fixed_parameters = maybe_unserialize($action['fixed_parameters']);
        $payload = [];

        if (is_array($fixed_parameters) && !empty($fixed_parameters)) {
            foreach ($fixed_parameters as $key => $value) {
                $payload[$key] = $value;
            }
        }

        foreach ($mappings as $form_field_id => $payload_key) {
            if (isset($consolidatedEntries[$form_field_id])) {
                $combined_value = implode(' ', $consolidatedEntries[$form_field_id]);
                $payload[$payload_key] = $combined_value;
            }
        }

        $actionUrl = $action['url'];
        $apiKey = get_option('sidetracker_api_key');
        sidetracker_make_api_call($actionUrl, $payload, $apiKey);
    }
}


?>
