<?php
add_action('woocommerce_checkout_order_processed', 'custom_wc_checkout_order_processed', 10, 1);

function custom_wc_checkout_order_processed($order_id) {
    $order = wc_get_order($order_id);
    $order_data = $order->get_data();
    sidetracker_log('WooCommerce Checkout Order Processed for Order ID: ' . $order_id);

    global $wpdb;
    $table_name = $wpdb->prefix . 'sidetracker_actions';
    $actions = $wpdb->get_results($wpdb->prepare("SELECT * FROM $table_name WHERE type = 'wc-checkout'"), ARRAY_A);

    if (empty($actions)) {
        sidetracker_log('No actions found for this WooCommerce checkout.');
        return;
    }

    foreach ($actions as $action) {
        $mappings = maybe_unserialize($action['mappings']);
        $fixed_parameters = maybe_unserialize($action['fixed_parameters']);
        $payload = [];

        if (is_array($fixed_parameters) && !empty($fixed_parameters)) {
            foreach ($fixed_parameters as $key => $value) {
                $payload[$key] = $value;
            }
        }

        foreach ($mappings as $field_id => $payload_key) {
            list($field_group, $field_name) = array_pad(explode('+', $field_id, 2), 2, null);

            if ($field_group && $field_name && isset($order_data[$field_group]) && is_array($order_data[$field_group]) && array_key_exists($field_name, $order_data[$field_group])) {
                $payload[$payload_key] = $order_data[$field_group][$field_name];
            } else if (isset($order_data[$field_id])) {
                $payload[$payload_key] = $order_data[$field_id];
            }
        }

        $actionUrl = $action['url'];
        $apiKey = get_option('sidetracker_api_key');
        sidetracker_make_api_call($actionUrl, $payload, $apiKey);
    }
}

?>