<?php
/*
Plugin Name: Sidetracker
Description: Integrates custom form submissions and WooCommerce checkouts with Sidetracker API.
Version: 1.0
Author: The Sidetracker Team
*/

function sidetracker_log($message) {
    $upload_dir = wp_upload_dir();
    $log_dir = $upload_dir['basedir'] . '/sidetracker';
    if (!file_exists($log_dir)) {
        wp_mkdir_p($log_dir);
    }
    $log_file = $log_dir . '/sidetracker-log.log';
    
    if (is_array($message)) {
        $message = print_r($message, true);
    } else {
        $message = sanitize_text_field($message);
    }
    
    error_log(date('Y-m-d H:i:s') . " " . $message . "\n", 3, $log_file);
}

function sidetracker_enqueue_scripts() {
    wp_enqueue_script('sidetracker-session', plugins_url('/js/sidetracker-session.js', __FILE__), array('jquery'));
    wp_localize_script('sidetracker-session', 'ajaxurl', admin_url('admin-ajax.php'));
}
add_action('wp_enqueue_scripts', 'sidetracker_enqueue_scripts');


add_action('wp_ajax_nopriv_sidetracker_set_session_id', 'sidetracker_set_session_id');
add_action('wp_ajax_sidetracker_set_session_id', 'sidetracker_set_session_id');

function sidetracker_set_session_id() {
    if (!session_id()) {
        session_start();
    }

    if (isset($_POST['sidetracker_session_id'])) {
        $_SESSION['sidetracker_custom_session_id'] = sanitize_text_field($_POST['sidetracker_session_id']);
    }
    
    wp_send_json_success('Session ID set successfully.');
}

function sidetracker_create_custom_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'sidetracker_actions';

    $charset_collate = $wpdb->get_charset_collate();

    $sql = "CREATE TABLE $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        name varchar(255) NOT NULL,
        type varchar(255) NOT NULL,
        url text NOT NULL,
        trigger_id text,
        wpform_id mediumint(9) DEFAULT NULL,
        gravityform_id mediumint(9) DEFAULT NULL,
        fixed_parameters text,
        mappings text NOT NULL,
        PRIMARY KEY  (id)
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}

function custom_enqueue_sidetracker_script() {
    wp_enqueue_script('sidetracker-session', plugins_url('/js/sidetracker-session.js', __FILE__), array('jquery'), null, true);
}
add_action('wp_enqueue_scripts', 'custom_enqueue_sidetracker_script');

register_activation_hook(__FILE__, 'sidetracker_create_custom_table');

require_once plugin_dir_path(__FILE__) . 'admin/settings-page.php';
require_once plugin_dir_path(__FILE__) . 'includes/form-submission-handler.php';
require_once plugin_dir_path(__FILE__) . 'includes/wc-checkout-handler.php';
require_once plugin_dir_path(__FILE__) . 'includes/utilities.php';

?>
